<?php
require_once('../../../config.php');
require_once($CFG->dirroot . '/backup/util/includes/restore_includes.php');

raise_memory_limit(MEMORY_EXTRA);
$courseid = required_param('courseid', PARAM_INT);
$pathnamehash = required_param('pathnamehash', PARAM_ALPHANUM);
$contenthash = required_param('contenthash', PARAM_ALPHANUM);
$stage   = required_param('stage', PARAM_INT);

$context = context_course::instance($courseid);
list($context, $course, $cm) = get_context_info_array($context->id);

$PAGE->set_url(new moodle_url('/local/dabar/upload/select.php', array('courseid'=>$course->id)));
$PAGE->set_context($context);
$PAGE->set_pagelayout('admin');
$PAGE->add_body_class('path-backup');

require_login($course->id);
require_capability('local/dabar:api_upload', $context);

$PAGE->set_title($course->shortname . ': ' . get_string('currentstage'.$stage, 'local_dabar'));
$PAGE->set_heading($course->fullname);
echo $OUTPUT->header();

$fs = get_file_storage();
$filepath = restore_controller::get_tempdir_name($contextid, $USER->id);
$backuptempdir = make_backup_temp_directory('', false);
$storedfile = $fs->get_file_by_hash($pathnamehash);
$fb = get_file_packer('application/vnd.moodle.backup');
$fb->extract_to_pathname($storedfile, $backuptempdir . '/' . $filepath . '/');
$details = backup_general_helper::get_backup_information($filepath);
$details_filtered = get_backup_information($filepath);

$filtered_details = array();
$filtered_details['type'] = $details_filtered->type;
if($details_filtered->type == 'course'){
	$filtered_details['title'] = $details_filtered->course->fullname;
	$filtered_details['summary'] = $details_filtered->course->summary;
}
elseif($details_filtered->type == 'activity'){
	$filtered_details['title'] = $details_filtered->activities[0]->title;
	$filtered_details['summary'] = '';
}
else{
	$filtered_details['title'] = '';
}
$filtered_details['language'] = $details_filtered->lang;
$filtered_details['backup_release'] = $details_filtered->backup_release;
$filtered_details['backup_date'] = $details_filtered->backup_date;
$filtered_details['url'] = $details_filtered->original_wwwroot;
$filtered_details['activities'] = $details_filtered->activities;
if($details_filtered->root_settings['questionbank']){
	$questionbank = new stdClass();
	$questionbank->modulename = 'questionbank';
	$questionbank->title = '';
	$filtered_details['activities'][] = $questionbank;
}

$SESSION->details = json_encode($filtered_details);

$count = 0;

function backup_detail_pair($label, $value, &$count) {
	$count ++;
	$html  = html_writer::start_tag('div', array('class' => 'detail-pair'));
	$html .= html_writer::tag('label', $label, array('class' => 'detail-pair-label', 'for' => 'detail-pair-value-'.$count));
	$html .= html_writer::tag('div', $value, array('class' => 'detail-pair-value pl-2', 'name' => 'detail-pair-value-'.$count));
	$html .= html_writer::end_tag('div');
	return $html;
}

$yestick = $OUTPUT->pix_icon('i/valid', get_string('yes'));
$notick = $OUTPUT->pix_icon('i/invalid', get_string('no'));

$html = get_progress_bar($stage);

$html  .= html_writer::start_tag('div', array('class' => 'backup-restore'));

$html .= html_writer::start_tag('div', array('class' => 'backup-section'));
$html .= $OUTPUT->heading(get_string('backupdetails', 'backup'), 2, array('class' => 'header'));
$html .= backup_detail_pair(get_string('backuptype', 'backup'), get_string('backuptype'.$details->type, 'backup'), $count);
$html .= backup_detail_pair(get_string('backupformat', 'backup'), get_string('backupformat'.$details->format, 'backup'), $count);
$html .= backup_detail_pair(get_string('backupdate', 'backup'), userdate($details->backup_date), $count);
$html .= backup_detail_pair(get_string('backupversion', 'backup'), html_writer::tag('span', $details->backup_release, array('class' => 'moodle_release')), $count);
$html .= html_writer::end_tag('div');

$html .= html_writer::start_tag('div', array('class' => 'backup-section settings-section'));
$html .= $OUTPUT->heading(get_string('backupsettings', 'backup'), 2, array('class' => 'header'));
foreach ($details->root_settings as $label => $value) {
	if ($label == 'users' || $label == 'anonymize' || $label == 'activities' || $label == 'blocks' || $label == 'questionbank') {
		$html .= backup_detail_pair(get_string('rootsetting'.str_replace('_', '', $label), 'backup'), $value ? $yestick : $notick, $count);
	}
	else{
		continue;
	}
}
$html .= html_writer::end_tag('div');

if($details->root_settings['users'] && !$details->root_settings['anonymize']){
	$html .= html_writer::start_tag('div', array('class' => 'alert alert-danger font-weight-bold'));
	$html .= get_string('backup_user_data_warinig', 'local_dabar');
	$html .= html_writer::end_tag('div');
}

if ($details->type === 'course') {
	$html .= html_writer::start_tag('div', array('class' => 'backup-section'));
	$html .= $OUTPUT->heading(get_string('backupcoursedetails', 'backup'), 2, array('class' => 'header'));
	$html .= backup_detail_pair(get_string('coursetitle', 'backup'), $details->course->title, $count);
	
	$html .= html_writer::start_tag('div', array('class' => 'backup-sub-section'));
	$html .= $OUTPUT->heading(get_string('backupcoursesections', 'backup'), 3, array('class' => 'subheader'));
	foreach ($details->sections as $key => $section) {
		$included = $key.'_included';
		$userinfo = $key.'_userinfo';
		if ($section->settings[$included] && $section->settings[$userinfo]) {
			$value = get_string('sectionincanduser', 'backup');
		} else if ($section->settings[$included]) {
			$value = get_string('sectioninc', 'backup');
		} else {
			continue;
		}
		$html .= backup_detail_pair(get_string('backupcoursesection', 'backup', $section->title), $value, $count);
		$table = null;
		foreach ($details->activities as $activitykey => $activity) {
			if ($activity->sectionid != $section->sectionid) {
				continue;
			}
			if (empty($table)) {
				$table = new html_table();
				$table->head = array(get_string('module', 'backup'), get_string('title', 'backup'), get_string('userinfo', 'backup'));
				$table->colclasses = array('modulename', 'moduletitle', 'userinfoincluded');
				$table->align = array('left', 'left', 'center');
				$table->attributes = array('class' => 'activitytable generaltable');
				$table->data = array();
			}
			$name = get_string('pluginname', $activity->modulename);
			$icon = new image_icon('icon', $name, $activity->modulename, array('class' => 'iconlarge icon-pre'));
			$table->data[] = array(
					$OUTPUT->render($icon).$name,
					$activity->title,
					($activity->settings[$activitykey.'_userinfo']) ? $yestick : $notick,
			);
		}
		if (!empty($table)) {
			$html .= backup_detail_pair(get_string('sectionactivities', 'backup'), html_writer::table($table), $count);
		}
		
	}
	$html .= html_writer::end_tag('div');
	$html .= html_writer::end_tag('div');
}
elseif($details->type === 'activity'){
	$html .= html_writer::start_tag('div', array('class' => 'backup-section'));
	$html .= $OUTPUT->heading(get_string('backupcoursedetails', 'backup'), 2, array('class' => 'header'));
	$table = null;
	foreach ($details->activities as $activitykey => $activity) {
		if (empty($table)) {
			$table = new html_table();
			$table->head = array(get_string('module', 'backup'), get_string('title', 'backup'), get_string('userinfo', 'backup'));
			$table->colclasses = array('modulename', 'moduletitle', 'userinfoincluded');
			$table->align = array('left', 'left', 'center');
			$table->attributes = array('class' => 'activitytable generaltable');
			$table->data = array();
		}
		$name = get_string('pluginname', $activity->modulename);
		$icon = new image_icon('icon', $name, $activity->modulename, array('class' => 'iconlarge icon-pre'));
		$table->data[] = array(
			$OUTPUT->render($icon).$name,
			$activity->title,
			($activity->settings[$activitykey.'_userinfo']) ? $yestick : $notick,
		);
	}
	if (!empty($table)) {
		$html .= backup_detail_pair(get_string('sectionactivities', 'backup'), html_writer::table($table), $count);
	}
	$html .= html_writer::end_tag('div');
}

$nextstageurl = new moodle_url('/local/dabar/upload/metadata.php', array(
	'courseid'  => $context->instanceid,
	'pathnamehash' => $pathnamehash,
	'contenthash' => $contenthash,
	'stage'     => 2)
);

$html .= $OUTPUT->single_button($nextstageurl, get_string('continue'), 'post');
$html .= html_writer::end_tag('div');

echo $html;

echo $OUTPUT->footer();